@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '1.17';
+$VERSION = '1.18';
 
 #----------------------------------------------------------------------------
 # Library Modules
@@ -873,6 +873,7 @@ sub store_report {
         'INSERT' => {
             CPANSTATS => 'INSERT INTO cpanstats (guid,state,postdate,tester,dist,version,platform,perl,osname,osvers,fulldate,type) VALUES (?,?,?,?,?,?,?,?,?,?,?,?)',
             RELEASE   => 'INSERT INTO release_data (id,guid,dist,version,oncpan,distmat,perlmat,patched,pass,fail,na,unknown) VALUES (?,?,?,?,?,?,?,?,?,?,?,?)',
+            PASSES    => 'INSERT IGNORE passreports SET platform=?, osname=?, perl=?, dist=?, postdate=?',
         },
         'UPDATE' => {
             CPANSTATS => 'UPDATE cpanstats SET state=?,postdate=?,tester=?,dist=?,version=?,platform=?,perl=?,osname=?,osvers=?,fulldate=?,type=? WHERE guid=?',
@@ -958,6 +959,16 @@ sub store_report {
         }
     }
 
+    if($fields{state} eq 'pass') {
+        $fields{perl} =~ s/\s.*//;  # only need to know the main release
+        $self->{CPANSTATS}->do_query($SQL{INSERT}{PASSES},
+            $fields{platform},
+            $fields{osname},
+            $fields{perl},
+            $fields{dist},
+            $fields{postdate});
+    }
+
     if((++$self->{stat_count} % 500) == 0) {
         $self->commit;
     }
@@ -1750,6 +1761,11 @@ discussion mailing list.
   CPAN Testers Discuss mailing list
     - http://lists.cpan.org/showlist.cgi?name=cpan-testers-discuss
 
+=head1 BUCKETS
+
+  beta6 - 2014-01-21
+  beta7 - 2014-11-12
+
 =head1 BUGS, PATCHES & FIXES
 
 There are no known bugs at the time of this release. However, if you spot a
@@ -1793,7 +1809,7 @@ changes, a new name was given to the distribution.
 
 =head2 CPAN-Testers-Data-Generator
 
-  Original author:    Barbie       <barbie@cpan.org>   (C) 2008-2014
+  Original author:    Barbie       <barbie@cpan.org>   (C) 2008-2015
 
 =head1 LICENSE
 
